@@ -7,7 +7,7 @@ from ..response import ok, error
 
 def _format(response):
     response['amount'] = response['amount'] / 100
-    response['status_detail'] = 'accredited' if response['status'] == 'approved' else response['status']
+    #response['status_detail'] = 'accredited' if response['status'] == 'approved' else response['status']
 
     return response
 
